==> haskell-text-builder-dev-0.3.3.2-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder-dev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-builder-dev
version:              0.3.3.2
visibility:           public
id:                   text-builder-dev-0.3.3.2-CRqEc8iJVuMKnT1IjcFWe3
key:                  text-builder-dev-0.3.3.2-CRqEc8iJVuMKnT1IjcFWe3
license:              MIT
copyright:            (c) 2022, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder-dev
synopsis:             Edge of developments for "text-builder"
description:
    This is a development version of \"text-builder\".
    All experimentation and feature development happens here.
    The API can change drastically.
    For a more stable API use \"text-builder\",
    which is now just a wrapper over this package.

category:             Text
abi:                  433c3b37b08e2b3a217b5c9328043dfe
exposed:              True
exposed-modules:      TextBuilderDev
hidden-modules:
    TextBuilderDev.Allocator TextBuilderDev.Unicode
    TextBuilderDev.Utf16View TextBuilderDev.Utf8View
    TextBuilderDev.Prelude

import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-builder-dev-0.3.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-builder-dev-0.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-dev
hs-libraries:         HStext-builder-dev-0.3.3.2-CRqEc8iJVuMKnT1IjcFWe3
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    deferred-folds-0.9.18.6-2ys39PrhbvW91umLutm1VH
    isomorphism-class-0.1.0.11-7P55LQVFTifEQWJHDBlg9k
    split-0.2.5-IR1Zqi63dhsCAOfFAiRIkz text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-dev/html/text-builder-dev.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-dev/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-dev-0.3.3.2-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder-dev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-builder-dev
version:              0.3.3.2
visibility:           public
id:                   text-builder-dev-0.3.3.2-C76BwsP5Nn8GZve3zmkf4s
key:                  text-builder-dev-0.3.3.2-C76BwsP5Nn8GZve3zmkf4s
license:              MIT
copyright:            (c) 2022, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder-dev
synopsis:             Edge of developments for "text-builder"
description:
    This is a development version of \"text-builder\".
    All experimentation and feature development happens here.
    The API can change drastically.
    For a more stable API use \"text-builder\",
    which is now just a wrapper over this package.

category:             Text
abi:                  53baae8a95cca8c3c464e1844405a1d7
exposed:              True
exposed-modules:      TextBuilderDev
hidden-modules:
    TextBuilderDev.Allocator TextBuilderDev.Unicode
    TextBuilderDev.Utf16View TextBuilderDev.Utf8View
    TextBuilderDev.Prelude

import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-builder-dev-0.3.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-builder-dev-0.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-dev
hs-libraries:         HStext-builder-dev-0.3.3.2-C76BwsP5Nn8GZve3zmkf4s
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    deferred-folds-0.9.18.6-151U4nii3mME1yg4ufN27x
    isomorphism-class-0.1.0.11-F2KHmXTLAAwH2z73fF4LVu
    split-0.2.5-1ZxzpQu4N6MJreBZLkb7G2 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-dev/html/text-builder-dev.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-dev/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
